@@ -5,6 +5,7 @@ from .except_debug import except_debug as useExceptDebug
 from .run_in_thread import run_in_thread as useRunInThread
 from .listify import listify as useListify
 from .cache import cached_property as useCachedProperty
+from .retry import Retry as useRetry
 
 
 class Decorator:
@@ -15,6 +16,7 @@ class Decorator:
     run_in_thread = useRunInThread
     listify = useListify
     cached_property = useCachedProperty
+    retry = useRetry
 
 
 useDecorator = Decorator
